An Actor represents an entity that is allowed to perform certain actions.
The following format is used to distinguish between the different types of actors that GitHub supports:

| Actor Type | Format                        | Example                    |
|------------|-------------------------------|----------------------------|
| User       | `@<user-login>`               | `@netomi`                  |
| Team       | `@<organization>/<team-slug>` | `@OtterdogTest/committers` |
| App        | `<app-slug>`                  | `eclipse-eca-validation`   |
